@@ -1,16 +1,16 @@
 
-# This library is free software; you can redistribute it and/or
+# This R package is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
 # License as published by the Free Software Foundation; either
 # version 2 of the License, or (at your option) any later version.
 #
-# This library is distributed in the hope that it will be useful,
+# This R package is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Library General Public License for more details.
 #
 # You should have received a copy of the GNU Library General
-# Public License along with this library; if not, write to the
+# Public License along with this R package; if not, write to the
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
@@ -32,44 +32,52 @@
 #  format.timeDate           Formats 'timeDate' as ISO conform string
 ################################################################################
 
+## format.timeDate <-
+##     function(x, format = "", tz = "", usetz = FALSE, ...)
+## {
+##     if (!inherits(x, "timeDate"))
+##         stop("wrong class")
+
+##     isoFormat <- "%Y-%m-%d %H:%M:%S"
+##     isoDate <- "%Y-%m-%d"
+##     FinCenter <- if (tz != "") tz else x@FinCenter
+
+##     # tz = "GMT" important to avoid confusion when DST in force
+##     charvec <- format(x@Data, isoFormat, tz = "GMT")
+
+##     ans <- .formatFinCenter(charvec, FinCenter, type = "gmt2any")
+
+##     # tz = "GMT" important to avoid confusion when DST in force
+##     ans <- format(as.POSIXct(ans, isoFormat, tz = "GMT"),
+##                   format = format, tz = "GMT")
+
+##     # should add tz from table in formatFinCenter
+##     if (usetz)
+##         ans <- paste(ans, x@FinCenter)
+
+##     # Return
+##     ans
+## }
+
+
 format.timeDate <-
     function(x, format = "", tz = "", usetz = FALSE, ...)
 {
     if (!inherits(x, "timeDate"))
         stop("wrong class")
 
-    if (format != "") x@format <- format
-    if (tz != "") x@FinCenter <- tz
+    FinCenter <- if (tz != "") tz else x@FinCenter
+
+    num <- .formatFinCenterNum(as.numeric(x@Data), FinCenter, type = "gmt2any")
+    ans <- format(as.POSIXct(num, origin = "1970-01-01", tz = "GMT"),
+                  tz = "GMT", format = format)
 
-    charvec = .timeDateData2charvec(x)
     # should add tz from table in formatFinCenter
-    # ans <- ifelse(usetz, paste(charvec, x@FinCenter), charvec)
+    if (usetz)
+        ans <- paste(ans, x@FinCenter)
 
     # Return
-    charvec
-}
-
-# ------------------------------------------------------------------------------
-
-.timeDateData2charvec <-
-    function(object)
-{
-    isoFormat <- "%Y-%m-%d %H:%M:%S"
-    FinCenter <- object@FinCenter
-    format <- object@format
-
-    # tz = "GMT" important to avoid confusion when DST in force
-    charvec <- format.POSIXct(object@Data, isoFormat)
-
-    ans <- .formatFinCenter(charvec, FinCenter, type = "gmt2any")
-    # ans <- format(as.POSIXct(ans))
-    # tz = "GMT" important to avoid confusion when DST in force
-    if (!identical(format, isoFormat))
-        ans <- format(strptime(ans, isoFormat, tz = "GMT"), format = format)
-
     ans
 }
 
-
 ################################################################################
-
